//    SPDX-License-Identifier: LGPL-3.0-or-later
/*
    This file is part of FlexiBLAS, a BLAS/LAPACK interface wrapper library.
    Copyright (C) 2013-2024 Martin Koehler

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 3 of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program; if not, write to the Free Software Foundation,
    Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/






#ifndef LAPACK_3_2_0_H

#define LAPACK_3_2_0_H

char *lapack_3_2_0 [] = {
    "cbdsqr",
    "cgbbrd",
    "cgbcon",
    "cgbequ",
    "cgbequb",
    "cgbrfs",
    "cgbsv",
    "cgbsvx",
    "cgbtf2",
    "cgbtrf",
    "cgbtrs",
    "cgebak",
    "cgebal",
    "cgebd2",
    "cgebrd",
    "cgecon",
    "cgeequ",
    "cgeequb",
    "cgees",
    "cgeesx",
    "cgeev",
    "cgeevx",
    "cgegs",
    "cgegv",
    "cgehd2",
    "cgehrd",
    "cgelq2",
    "cgelqf",
    "cgels",
    "cgelsd",
    "cgelss",
    "cgelsx",
    "cgelsy",
    "cgeql2",
    "cgeqlf",
    "cgeqp3",
    "cgeqpf",
    "cgeqr2",
    "cgeqrf",
    "cgerfs",
    "cgerq2",
    "cgerqf",
    "cgesc2",
    "cgesdd",
    "cgesv",
    "cgesvd",
    "cgesvx",
    "cgetc2",
    "cgetf2",
    "cgetrf",
    "cgetri",
    "cgetrs",
    "cggbak",
    "cggbal",
    "cgges",
    "cggesx",
    "cggev",
    "cggevx",
    "cggglm",
    "cgghrd",
    "cgglse",
    "cggqrf",
    "cggrqf",
    "cggsvd",
    "cggsvp",
    "cgtcon",
    "cgtrfs",
    "cgtsv",
    "cgtsvx",
    "cgttrf",
    "cgttrs",
    "cgtts2",
    "chbev",
    "chbevd",
    "chbevx",
    "chbgst",
    "chbgv",
    "chbgvd",
    "chbgvx",
    "chbtrd",
    "checon",
    "cheequb",
    "cheev",
    "cheevd",
    "cheevr",
    "cheevx",
    "chegs2",
    "chegst",
    "chegv",
    "chegvd",
    "chegvx",
    "cherfs",
    "chesv",
    "chesvx",
    "chetd2",
    "chetf2",
    "chetrd",
    "chetrf",
    "chetri",
    "chetrs",
    "chfrk",
    "chgeqz",
    "chla_transtype",
    "chpcon",
    "chpev",
    "chpevd",
    "chpevx",
    "chpgst",
    "chpgv",
    "chpgvd",
    "chpgvx",
    "chprfs",
    "chpsv",
    "chpsvx",
    "chptrd",
    "chptrf",
    "chptri",
    "chptrs",
    "chsein",
    "chseqr",
    "clabrd",
    "clacgv",
    "clacn2",
    "clacon",
    "clacp2",
    "clacpy",
    "clacrm",
    "clacrt",
    "cladiv",
    "claed0",
    "claed7",
    "claed8",
    "claein",
    "claesy",
    "claev2",
    "clag2z",
    "clags2",
    "clagtm",
    "clahef",
    "clahqr",
    "clahr2",
    "clahrd",
    "claic1",
    "clals0",
    "clalsa",
    "clalsd",
    "clangb",
    "clange",
    "clangt",
    "clanhb",
    "clanhe",
    "clanhf",
    "clanhp",
    "clanhs",
    "clanht",
    "clansb",
    "clansp",
    "clansy",
    "clantb",
    "clantp",
    "clantr",
    "clapll",
    "clapmt",
    "claqgb",
    "claqge",
    "claqhb",
    "claqhe",
    "claqhp",
    "claqp2",
    "claqps",
    "claqr0",
    "claqr1",
    "claqr2",
    "claqr3",
    "claqr4",
    "claqr5",
    "claqsb",
    "claqsp",
    "claqsy",
    "clar1v",
    "clar2v",
    "clarcm",
    "clarf",
    "clarfb",
    "clarfg",
    "clarfp",
    "clarft",
    "clarfx",
    "clargv",
    "clarnv",
    "clarrv",
    "clartg",
    "clartv",
    "clarz",
    "clarzb",
    "clarzt",
    "clascl",
    "claset",
    "clasr",
    "classq",
    "claswp",
    "clasyf",
    "clatbs",
    "clatdf",
    "clatps",
    "clatrd",
    "clatrs",
    "clatrz",
    "clatzm",
    "clauu2",
    "clauum",
    "cpbcon",
    "cpbequ",
    "cpbrfs",
    "cpbstf",
    "cpbsv",
    "cpbsvx",
    "cpbtf2",
    "cpbtrf",
    "cpbtrs",
    "cpftrf",
    "cpftri",
    "cpftrs",
    "cpocon",
    "cpoequ",
    "cpoequb",
    "cporfs",
    "cposv",
    "cposvx",
    "cpotf2",
    "cpotrf",
    "cpotri",
    "cpotrs",
    "cppcon",
    "cppequ",
    "cpprfs",
    "cppsv",
    "cppsvx",
    "cpptrf",
    "cpptri",
    "cpptrs",
    "cpstf2",
    "cpstrf",
    "cptcon",
    "cpteqr",
    "cptrfs",
    "cptsv",
    "cptsvx",
    "cpttrf",
    "cpttrs",
    "cptts2",
    "crot",
    "cspcon",
    "cspmv",
    "cspr",
    "csprfs",
    "cspsv",
    "cspsvx",
    "csptrf",
    "csptri",
    "csptrs",
    "csrscl",
    "cstedc",
    "cstegr",
    "cstein",
    "cstemr",
    "csteqr",
    "csycon",
    "csyequb",
    "csymv",
    "csyr",
    "csyrfs",
    "csysv",
    "csysvx",
    "csytf2",
    "csytrf",
    "csytri",
    "csytrs",
    "ctbcon",
    "ctbrfs",
    "ctbtrs",
    "ctfsm",
    "ctftri",
    "ctfttp",
    "ctfttr",
    "ctgevc",
    "ctgex2",
    "ctgexc",
    "ctgsen",
    "ctgsja",
    "ctgsna",
    "ctgsy2",
    "ctgsyl",
    "ctpcon",
    "ctprfs",
    "ctptri",
    "ctptrs",
    "ctpttf",
    "ctpttr",
    "ctrcon",
    "ctrevc",
    "ctrexc",
    "ctrrfs",
    "ctrsen",
    "ctrsna",
    "ctrsyl",
    "ctrti2",
    "ctrtri",
    "ctrtrs",
    "ctrttf",
    "ctrttp",
    "ctzrqf",
    "ctzrzf",
    "cung2l",
    "cung2r",
    "cungbr",
    "cunghr",
    "cungl2",
    "cunglq",
    "cungql",
    "cungqr",
    "cungr2",
    "cungrq",
    "cungtr",
    "cunm2l",
    "cunm2r",
    "cunmbr",
    "cunmhr",
    "cunml2",
    "cunmlq",
    "cunmql",
    "cunmqr",
    "cunmr2",
    "cunmr3",
    "cunmrq",
    "cunmrz",
    "cunmtr",
    "cupgtr",
    "cupmtr",
    "dbdsdc",
    "dbdsqr",
    "ddisna",
    "dgbbrd",
    "dgbcon",
    "dgbequ",
    "dgbequb",
    "dgbrfs",
    "dgbsv",
    "dgbsvx",
    "dgbtf2",
    "dgbtrf",
    "dgbtrs",
    "dgebak",
    "dgebal",
    "dgebd2",
    "dgebrd",
    "dgecon",
    "dgeequ",
    "dgeequb",
    "dgees",
    "dgeesx",
    "dgeev",
    "dgeevx",
    "dgegs",
    "dgegv",
    "dgehd2",
    "dgehrd",
    "dgejsv",
    "dgelq2",
    "dgelqf",
    "dgels",
    "dgelsd",
    "dgelss",
    "dgelsx",
    "dgelsy",
    "dgeql2",
    "dgeqlf",
    "dgeqp3",
    "dgeqpf",
    "dgeqr2",
    "dgeqrf",
    "dgerfs",
    "dgerq2",
    "dgerqf",
    "dgesc2",
    "dgesdd",
    "dgesv",
    "dgesvd",
    "dgesvj",
    "dgesvx",
    "dgetc2",
    "dgetf2",
    "dgetrf",
    "dgetri",
    "dgetrs",
    "dggbak",
    "dggbal",
    "dgges",
    "dggesx",
    "dggev",
    "dggevx",
    "dggglm",
    "dgghrd",
    "dgglse",
    "dggqrf",
    "dggrqf",
    "dggsvd",
    "dggsvp",
    "dgsvj0",
    "dgsvj1",
    "dgtcon",
    "dgtrfs",
    "dgtsv",
    "dgtsvx",
    "dgttrf",
    "dgttrs",
    "dgtts2",
    "dhgeqz",
    "dhsein",
    "dhseqr",
    "disnan",
    "dlabad",
    "dlabrd",
    "dlacn2",
    "dlacon",
    "dlacpy",
    "dladiv",
    "dlae2",
    "dlaebz",
    "dlaed0",
    "dlaed1",
    "dlaed2",
    "dlaed3",
    "dlaed4",
    "dlaed5",
    "dlaed6",
    "dlaed7",
    "dlaed8",
    "dlaed9",
    "dlaeda",
    "dlaein",
    "dlaev2",
    "dlaexc",
    "dlag2",
    "dlag2s",
    "dlags2",
    "dlagtf",
    "dlagtm",
    "dlagts",
    "dlagv2",
    "dlahqr",
    "dlahr2",
    "dlahrd",
    "dlaic1",
    "dlaisnan",
    "dlaln2",
    "dlals0",
    "dlalsa",
    "dlalsd",
    "dlamc1",
    "dlamc2",
    "dlamc3",
    "dlamc4",
    "dlamc5",
    "dlamch",
    "dlamrg",
    "dlaneg",
    "dlangb",
    "dlange",
    "dlangt",
    "dlanhs",
    "dlansb",
    "dlansf",
    "dlansp",
    "dlanst",
    "dlansy",
    "dlantb",
    "dlantp",
    "dlantr",
    "dlanv2",
    "dlapll",
    "dlapmt",
    "dlapy2",
    "dlapy3",
    "dlaqgb",
    "dlaqge",
    "dlaqp2",
    "dlaqps",
    "dlaqr0",
    "dlaqr1",
    "dlaqr2",
    "dlaqr3",
    "dlaqr4",
    "dlaqr5",
    "dlaqsb",
    "dlaqsp",
    "dlaqsy",
    "dlaqtr",
    "dlar1v",
    "dlar2v",
    "dlarf",
    "dlarfb",
    "dlarfg",
    "dlarfp",
    "dlarft",
    "dlarfx",
    "dlargv",
    "dlarnv",
    "dlarra",
    "dlarrb",
    "dlarrc",
    "dlarrd",
    "dlarre",
    "dlarrf",
    "dlarrj",
    "dlarrk",
    "dlarrr",
    "dlarrv",
    "dlartg",
    "dlartv",
    "dlaruv",
    "dlarz",
    "dlarzb",
    "dlarzt",
    "dlas2",
    "dlascl",
    "dlasd0",
    "dlasd1",
    "dlasd2",
    "dlasd3",
    "dlasd4",
    "dlasd5",
    "dlasd6",
    "dlasd7",
    "dlasd8",
    "dlasda",
    "dlasdq",
    "dlasdt",
    "dlaset",
    "dlasq1",
    "dlasq2",
    "dlasq3",
    "dlasq4",
    "dlasq5",
    "dlasq6",
    "dlasr",
    "dlasrt",
    "dlassq",
    "dlasv2",
    "dlaswp",
    "dlasy2",
    "dlasyf",
    "dlat2s",
    "dlatbs",
    "dlatdf",
    "dlatps",
    "dlatrd",
    "dlatrs",
    "dlatrz",
    "dlatzm",
    "dlauu2",
    "dlauum",
    "dopgtr",
    "dopmtr",
    "dorg2l",
    "dorg2r",
    "dorgbr",
    "dorghr",
    "dorgl2",
    "dorglq",
    "dorgql",
    "dorgqr",
    "dorgr2",
    "dorgrq",
    "dorgtr",
    "dorm2l",
    "dorm2r",
    "dormbr",
    "dormhr",
    "dorml2",
    "dormlq",
    "dormql",
    "dormqr",
    "dormr2",
    "dormr3",
    "dormrq",
    "dormrz",
    "dormtr",
    "dpbcon",
    "dpbequ",
    "dpbrfs",
    "dpbstf",
    "dpbsv",
    "dpbsvx",
    "dpbtf2",
    "dpbtrf",
    "dpbtrs",
    "dpftrf",
    "dpftri",
    "dpftrs",
    "dpocon",
    "dpoequ",
    "dpoequb",
    "dporfs",
    "dposv",
    "dposvx",
    "dpotf2",
    "dpotrf",
    "dpotri",
    "dpotrs",
    "dppcon",
    "dppequ",
    "dpprfs",
    "dppsv",
    "dppsvx",
    "dpptrf",
    "dpptri",
    "dpptrs",
    "dpstf2",
    "dpstrf",
    "dptcon",
    "dpteqr",
    "dptrfs",
    "dptsv",
    "dptsvx",
    "dpttrf",
    "dpttrs",
    "dptts2",
    "drscl",
    "dsbev",
    "dsbevd",
    "dsbevx",
    "dsbgst",
    "dsbgv",
    "dsbgvd",
    "dsbgvx",
    "dsbtrd",
    "dsecnd",
    "dsfrk",
    "dsgesv",
    "dspcon",
    "dspev",
    "dspevd",
    "dspevx",
    "dspgst",
    "dspgv",
    "dspgvd",
    "dspgvx",
    "dsposv",
    "dsprfs",
    "dspsv",
    "dspsvx",
    "dsptrd",
    "dsptrf",
    "dsptri",
    "dsptrs",
    "dstebz",
    "dstedc",
    "dstegr",
    "dstein",
    "dstemr",
    "dsteqr",
    "dsterf",
    "dstev",
    "dstevd",
    "dstevr",
    "dstevx",
    "dsycon",
    "dsyequb",
    "dsyev",
    "dsyevd",
    "dsyevr",
    "dsyevx",
    "dsygs2",
    "dsygst",
    "dsygv",
    "dsygvd",
    "dsygvx",
    "dsyrfs",
    "dsysv",
    "dsysvx",
    "dsytd2",
    "dsytf2",
    "dsytrd",
    "dsytrf",
    "dsytri",
    "dsytrs",
    "dtbcon",
    "dtbrfs",
    "dtbtrs",
    "dtfsm",
    "dtftri",
    "dtfttp",
    "dtfttr",
    "dtgevc",
    "dtgex2",
    "dtgexc",
    "dtgsen",
    "dtgsja",
    "dtgsna",
    "dtgsy2",
    "dtgsyl",
    "dtpcon",
    "dtprfs",
    "dtptri",
    "dtptrs",
    "dtpttf",
    "dtpttr",
    "dtrcon",
    "dtrevc",
    "dtrexc",
    "dtrrfs",
    "dtrsen",
    "dtrsna",
    "dtrsyl",
    "dtrti2",
    "dtrtri",
    "dtrtrs",
    "dtrttf",
    "dtrttp",
    "dtzrqf",
    "dtzrzf",
    "dzsum1",
    "icmax1",
    "ieeeck",
    "ilaclc",
    "ilaclr",
    "iladiag",
    "iladlc",
    "iladlr",
    "ilaenv",
    "ilaprec",
    "ilaslc",
    "ilaslr",
    "ilatrans",
    "ilauplo",
    "ilaver",
    "ilazlc",
    "ilazlr",
    "iparmq",
    "izmax1",
    "lsame",
    "lsamen",
    "sbdsdc",
    "sbdsqr",
    "scsum1",
    "sdisna",
    "second",
    "sgbbrd",
    "sgbcon",
    "sgbequ",
    "sgbequb",
    "sgbrfs",
    "sgbsv",
    "sgbsvx",
    "sgbtf2",
    "sgbtrf",
    "sgbtrs",
    "sgebak",
    "sgebal",
    "sgebd2",
    "sgebrd",
    "sgecon",
    "sgeequ",
    "sgeequb",
    "sgees",
    "sgeesx",
    "sgeev",
    "sgeevx",
    "sgegs",
    "sgegv",
    "sgehd2",
    "sgehrd",
    "sgejsv",
    "sgelq2",
    "sgelqf",
    "sgels",
    "sgelsd",
    "sgelss",
    "sgelsx",
    "sgelsy",
    "sgeql2",
    "sgeqlf",
    "sgeqp3",
    "sgeqpf",
    "sgeqr2",
    "sgeqrf",
    "sgerfs",
    "sgerq2",
    "sgerqf",
    "sgesc2",
    "sgesdd",
    "sgesv",
    "sgesvd",
    "sgesvj",
    "sgesvx",
    "sgetc2",
    "sgetf2",
    "sgetrf",
    "sgetri",
    "sgetrs",
    "sggbak",
    "sggbal",
    "sgges",
    "sggesx",
    "sggev",
    "sggevx",
    "sggglm",
    "sgghrd",
    "sgglse",
    "sggqrf",
    "sggrqf",
    "sggsvd",
    "sggsvp",
    "sgsvj0",
    "sgsvj1",
    "sgtcon",
    "sgtrfs",
    "sgtsv",
    "sgtsvx",
    "sgttrf",
    "sgttrs",
    "sgtts2",
    "shgeqz",
    "shsein",
    "shseqr",
    "sisnan",
    "slabad",
    "slabrd",
    "slacn2",
    "slacon",
    "slacpy",
    "sladiv",
    "slae2",
    "slaebz",
    "slaed0",
    "slaed1",
    "slaed2",
    "slaed3",
    "slaed4",
    "slaed5",
    "slaed6",
    "slaed7",
    "slaed8",
    "slaed9",
    "slaeda",
    "slaein",
    "slaev2",
    "slaexc",
    "slag2",
    "slag2d",
    "slags2",
    "slagtf",
    "slagtm",
    "slagts",
    "slagv2",
    "slahqr",
    "slahr2",
    "slahrd",
    "slaic1",
    "slaisnan",
    "slaln2",
    "slals0",
    "slalsa",
    "slalsd",
    "slamc1",
    "slamc2",
    "slamc3",
    "slamc4",
    "slamc5",
    "slamch",
    "slamrg",
    "slaneg",
    "slangb",
    "slange",
    "slangt",
    "slanhs",
    "slansb",
    "slansf",
    "slansp",
    "slanst",
    "slansy",
    "slantb",
    "slantp",
    "slantr",
    "slanv2",
    "slapll",
    "slapmt",
    "slapy2",
    "slapy3",
    "slaqgb",
    "slaqge",
    "slaqp2",
    "slaqps",
    "slaqr0",
    "slaqr1",
    "slaqr2",
    "slaqr3",
    "slaqr4",
    "slaqr5",
    "slaqsb",
    "slaqsp",
    "slaqsy",
    "slaqtr",
    "slar1v",
    "slar2v",
    "slarf",
    "slarfb",
    "slarfg",
    "slarfp",
    "slarft",
    "slarfx",
    "slargv",
    "slarnv",
    "slarra",
    "slarrb",
    "slarrc",
    "slarrd",
    "slarre",
    "slarrf",
    "slarrj",
    "slarrk",
    "slarrr",
    "slarrv",
    "slartg",
    "slartv",
    "slaruv",
    "slarz",
    "slarzb",
    "slarzt",
    "slas2",
    "slascl",
    "slasd0",
    "slasd1",
    "slasd2",
    "slasd3",
    "slasd4",
    "slasd5",
    "slasd6",
    "slasd7",
    "slasd8",
    "slasda",
    "slasdq",
    "slasdt",
    "slaset",
    "slasq1",
    "slasq2",
    "slasq3",
    "slasq4",
    "slasq5",
    "slasq6",
    "slasr",
    "slasrt",
    "slassq",
    "slasv2",
    "slaswp",
    "slasy2",
    "slasyf",
    "slatbs",
    "slatdf",
    "slatps",
    "slatrd",
    "slatrs",
    "slatrz",
    "slatzm",
    "slauu2",
    "slauum",
    "sopgtr",
    "sopmtr",
    "sorg2l",
    "sorg2r",
    "sorgbr",
    "sorghr",
    "sorgl2",
    "sorglq",
    "sorgql",
    "sorgqr",
    "sorgr2",
    "sorgrq",
    "sorgtr",
    "sorm2l",
    "sorm2r",
    "sormbr",
    "sormhr",
    "sorml2",
    "sormlq",
    "sormql",
    "sormqr",
    "sormr2",
    "sormr3",
    "sormrq",
    "sormrz",
    "sormtr",
    "spbcon",
    "spbequ",
    "spbrfs",
    "spbstf",
    "spbsv",
    "spbsvx",
    "spbtf2",
    "spbtrf",
    "spbtrs",
    "spftrf",
    "spftri",
    "spftrs",
    "spocon",
    "spoequ",
    "spoequb",
    "sporfs",
    "sposv",
    "sposvx",
    "spotf2",
    "spotrf",
    "spotri",
    "spotrs",
    "sppcon",
    "sppequ",
    "spprfs",
    "sppsv",
    "sppsvx",
    "spptrf",
    "spptri",
    "spptrs",
    "spstf2",
    "spstrf",
    "sptcon",
    "spteqr",
    "sptrfs",
    "sptsv",
    "sptsvx",
    "spttrf",
    "spttrs",
    "sptts2",
    "srscl",
    "ssbev",
    "ssbevd",
    "ssbevx",
    "ssbgst",
    "ssbgv",
    "ssbgvd",
    "ssbgvx",
    "ssbtrd",
    "ssfrk",
    "sspcon",
    "sspev",
    "sspevd",
    "sspevx",
    "sspgst",
    "sspgv",
    "sspgvd",
    "sspgvx",
    "ssprfs",
    "sspsv",
    "sspsvx",
    "ssptrd",
    "ssptrf",
    "ssptri",
    "ssptrs",
    "sstebz",
    "sstedc",
    "sstegr",
    "sstein",
    "sstemr",
    "ssteqr",
    "ssterf",
    "sstev",
    "sstevd",
    "sstevr",
    "sstevx",
    "ssycon",
    "ssyequb",
    "ssyev",
    "ssyevd",
    "ssyevr",
    "ssyevx",
    "ssygs2",
    "ssygst",
    "ssygv",
    "ssygvd",
    "ssygvx",
    "ssyrfs",
    "ssysv",
    "ssysvx",
    "ssytd2",
    "ssytf2",
    "ssytrd",
    "ssytrf",
    "ssytri",
    "ssytrs",
    "stbcon",
    "stbrfs",
    "stbtrs",
    "stfsm",
    "stftri",
    "stfttp",
    "stfttr",
    "stgevc",
    "stgex2",
    "stgexc",
    "stgsen",
    "stgsja",
    "stgsna",
    "stgsy2",
    "stgsyl",
    "stpcon",
    "stprfs",
    "stptri",
    "stptrs",
    "stpttf",
    "stpttr",
    "strcon",
    "strevc",
    "strexc",
    "strrfs",
    "strsen",
    "strsna",
    "strsyl",
    "strti2",
    "strtri",
    "strtrs",
    "strttf",
    "strttp",
    "stzrqf",
    "stzrzf",
    "xerbla",
    "xerbla_array",
    "zbdsqr",
    "zcgesv",
    "zcposv",
    "zdrscl",
    "zgbbrd",
    "zgbcon",
    "zgbequ",
    "zgbequb",
    "zgbrfs",
    "zgbsv",
    "zgbsvx",
    "zgbtf2",
    "zgbtrf",
    "zgbtrs",
    "zgebak",
    "zgebal",
    "zgebd2",
    "zgebrd",
    "zgecon",
    "zgeequ",
    "zgeequb",
    "zgees",
    "zgeesx",
    "zgeev",
    "zgeevx",
    "zgegs",
    "zgegv",
    "zgehd2",
    "zgehrd",
    "zgelq2",
    "zgelqf",
    "zgels",
    "zgelsd",
    "zgelss",
    "zgelsx",
    "zgelsy",
    "zgeql2",
    "zgeqlf",
    "zgeqp3",
    "zgeqpf",
    "zgeqr2",
    "zgeqrf",
    "zgerfs",
    "zgerq2",
    "zgerqf",
    "zgesc2",
    "zgesdd",
    "zgesv",
    "zgesvd",
    "zgesvx",
    "zgetc2",
    "zgetf2",
    "zgetrf",
    "zgetri",
    "zgetrs",
    "zggbak",
    "zggbal",
    "zgges",
    "zggesx",
    "zggev",
    "zggevx",
    "zggglm",
    "zgghrd",
    "zgglse",
    "zggqrf",
    "zggrqf",
    "zggsvd",
    "zggsvp",
    "zgtcon",
    "zgtrfs",
    "zgtsv",
    "zgtsvx",
    "zgttrf",
    "zgttrs",
    "zgtts2",
    "zhbev",
    "zhbevd",
    "zhbevx",
    "zhbgst",
    "zhbgv",
    "zhbgvd",
    "zhbgvx",
    "zhbtrd",
    "zhecon",
    "zheequb",
    "zheev",
    "zheevd",
    "zheevr",
    "zheevx",
    "zhegs2",
    "zhegst",
    "zhegv",
    "zhegvd",
    "zhegvx",
    "zherfs",
    "zhesv",
    "zhesvx",
    "zhetd2",
    "zhetf2",
    "zhetrd",
    "zhetrf",
    "zhetri",
    "zhetrs",
    "zhfrk",
    "zhgeqz",
    "zhpcon",
    "zhpev",
    "zhpevd",
    "zhpevx",
    "zhpgst",
    "zhpgv",
    "zhpgvd",
    "zhpgvx",
    "zhprfs",
    "zhpsv",
    "zhpsvx",
    "zhptrd",
    "zhptrf",
    "zhptri",
    "zhptrs",
    "zhsein",
    "zhseqr",
    "zlabrd",
    "zlacgv",
    "zlacn2",
    "zlacon",
    "zlacp2",
    "zlacpy",
    "zlacrm",
    "zlacrt",
    "zladiv",
    "zlaed0",
    "zlaed7",
    "zlaed8",
    "zlaein",
    "zlaesy",
    "zlaev2",
    "zlag2c",
    "zlags2",
    "zlagtm",
    "zlahef",
    "zlahqr",
    "zlahr2",
    "zlahrd",
    "zlaic1",
    "zlals0",
    "zlalsa",
    "zlalsd",
    "zlangb",
    "zlange",
    "zlangt",
    "zlanhb",
    "zlanhe",
    "zlanhf",
    "zlanhp",
    "zlanhs",
    "zlanht",
    "zlansb",
    "zlansp",
    "zlansy",
    "zlantb",
    "zlantp",
    "zlantr",
    "zlapll",
    "zlapmt",
    "zlaqgb",
    "zlaqge",
    "zlaqhb",
    "zlaqhe",
    "zlaqhp",
    "zlaqp2",
    "zlaqps",
    "zlaqr0",
    "zlaqr1",
    "zlaqr2",
    "zlaqr3",
    "zlaqr4",
    "zlaqr5",
    "zlaqsb",
    "zlaqsp",
    "zlaqsy",
    "zlar1v",
    "zlar2v",
    "zlarcm",
    "zlarf",
    "zlarfb",
    "zlarfg",
    "zlarfp",
    "zlarft",
    "zlarfx",
    "zlargv",
    "zlarnv",
    "zlarrv",
    "zlartg",
    "zlartv",
    "zlarz",
    "zlarzb",
    "zlarzt",
    "zlascl",
    "zlaset",
    "zlasr",
    "zlassq",
    "zlaswp",
    "zlasyf",
    "zlat2c",
    "zlatbs",
    "zlatdf",
    "zlatps",
    "zlatrd",
    "zlatrs",
    "zlatrz",
    "zlatzm",
    "zlauu2",
    "zlauum",
    "zpbcon",
    "zpbequ",
    "zpbrfs",
    "zpbstf",
    "zpbsv",
    "zpbsvx",
    "zpbtf2",
    "zpbtrf",
    "zpbtrs",
    "zpftrf",
    "zpftri",
    "zpftrs",
    "zpocon",
    "zpoequ",
    "zpoequb",
    "zporfs",
    "zposv",
    "zposvx",
    "zpotf2",
    "zpotrf",
    "zpotri",
    "zpotrs",
    "zppcon",
    "zppequ",
    "zpprfs",
    "zppsv",
    "zppsvx",
    "zpptrf",
    "zpptri",
    "zpptrs",
    "zpstf2",
    "zpstrf",
    "zptcon",
    "zpteqr",
    "zptrfs",
    "zptsv",
    "zptsvx",
    "zpttrf",
    "zpttrs",
    "zptts2",
    "zrot",
    "zspcon",
    "zspmv",
    "zspr",
    "zsprfs",
    "zspsv",
    "zspsvx",
    "zsptrf",
    "zsptri",
    "zsptrs",
    "zstedc",
    "zstegr",
    "zstein",
    "zstemr",
    "zsteqr",
    "zsycon",
    "zsyequb",
    "zsymv",
    "zsyr",
    "zsyrfs",
    "zsysv",
    "zsysvx",
    "zsytf2",
    "zsytrf",
    "zsytri",
    "zsytrs",
    "ztbcon",
    "ztbrfs",
    "ztbtrs",
    "ztfsm",
    "ztftri",
    "ztfttp",
    "ztfttr",
    "ztgevc",
    "ztgex2",
    "ztgexc",
    "ztgsen",
    "ztgsja",
    "ztgsna",
    "ztgsy2",
    "ztgsyl",
    "ztpcon",
    "ztprfs",
    "ztptri",
    "ztptrs",
    "ztpttf",
    "ztpttr",
    "ztrcon",
    "ztrevc",
    "ztrexc",
    "ztrrfs",
    "ztrsen",
    "ztrsna",
    "ztrsyl",
    "ztrti2",
    "ztrtri",
    "ztrtrs",
    "ztrttf",
    "ztrttp",
    "ztzrqf",
    "ztzrzf",
    "zung2l",
    "zung2r",
    "zungbr",
    "zunghr",
    "zungl2",
    "zunglq",
    "zungql",
    "zungqr",
    "zungr2",
    "zungrq",
    "zungtr",
    "zunm2l",
    "zunm2r",
    "zunmbr",
    "zunmhr",
    "zunml2",
    "zunmlq",
    "zunmql",
    "zunmqr",
    "zunmr2",
    "zunmr3",
    "zunmrq",
    "zunmrz",
    "zunmtr",
    "zupgtr",
    "zupmtr",
    NULL
};

char *lapack_3_2_0_xblas[] = {
    "cgbrfsx",
    "cgbsvxx",
    "cgerfsx",
    "cgesvxx",
    "cherfsx",
    "chesvxx",
    "cla_gbamv",
    "cla_gbrcond_c",
    "cla_gbrcond_x",
    "cla_gbrfsx_extended",
    "cla_gbrpvgrw",
    "cla_geamv",
    "cla_gercond_c",
    "cla_gercond_x",
    "cla_gerfsx_extended",
    "cla_heamv",
    "cla_hercond_c",
    "cla_hercond_x",
    "cla_herfsx_extended",
    "cla_herpvgrw",
    "cla_lin_berr",
    "cla_porcond_c",
    "cla_porcond_x",
    "cla_porfsx_extended",
    "cla_porpvgrw",
    "cla_rpvgrw",
    "cla_syamv",
    "cla_syrcond_c",
    "cla_syrcond_x",
    "cla_syrfsx_extended",
    "cla_syrpvgrw",
    "cla_wwaddw",
    "clarscl2",
    "clascl2",
    "cporfsx",
    "cposvxx",
    "csyrfsx",
    "csysvxx",
    "dgbrfsx",
    "dgbsvxx",
    "dgerfsx",
    "dgesvxx",
    "dla_gbamv",
    "dla_gbrcond",
    "dla_gbrfsx_extended",
    "dla_gbrpvgrw",
    "dla_geamv",
    "dla_gercond",
    "dla_gerfsx_extended",
    "dla_lin_berr",
    "dla_porcond",
    "dla_porfsx_extended",
    "dla_porpvgrw",
    "dla_rpvgrw",
    "dla_syamv",
    "dla_syrcond",
    "dla_syrfsx_extended",
    "dla_syrpvgrw",
    "dla_wwaddw",
    "dlarscl2",
    "dlascl2",
    "dporfsx",
    "dposvxx",
    "dsyrfsx",
    "dsysvxx",
    "sgbrfsx",
    "sgbsvxx",
    "sgerfsx",
    "sgesvxx",
    "sla_gbamv",
    "sla_gbrcond",
    "sla_gbrfsx_extended",
    "sla_gbrpvgrw",
    "sla_geamv",
    "sla_gercond",
    "sla_gerfsx_extended",
    "sla_lin_berr",
    "sla_porcond",
    "sla_porfsx_extended",
    "sla_porpvgrw",
    "sla_rpvgrw",
    "sla_syamv",
    "sla_syrcond",
    "sla_syrfsx_extended",
    "sla_syrpvgrw",
    "sla_wwaddw",
    "slarscl2",
    "slascl2",
    "sporfsx",
    "sposvxx",
    "ssyrfsx",
    "ssysvxx",
    "zgbrfsx",
    "zgbsvxx",
    "zgerfsx",
    "zgesvxx",
    "zherfsx",
    "zhesvxx",
    "zla_gbamv",
    "zla_gbrcond_c",
    "zla_gbrcond_x",
    "zla_gbrfsx_extended",
    "zla_gbrpvgrw",
    "zla_geamv",
    "zla_gercond_c",
    "zla_gercond_x",
    "zla_gerfsx_extended",
    "zla_heamv",
    "zla_hercond_c",
    "zla_hercond_x",
    "zla_herfsx_extended",
    "zla_herpvgrw",
    "zla_lin_berr",
    "zla_porcond_c",
    "zla_porcond_x",
    "zla_porfsx_extended",
    "zla_porpvgrw",
    "zla_rpvgrw",
    "zla_syamv",
    "zla_syrcond_c",
    "zla_syrcond_x",
    "zla_syrfsx_extended",
    "zla_syrpvgrw",
    "zla_wwaddw",
    "zlarscl2",
    "zlascl2",
    "zporfsx",
    "zposvxx",
    "zsyrfsx",
    "zsysvxx",
    NULL
};

#endif /* end of include guard: LAPACK_3_2_0_H */
